API Reference
=============

This section documents the main public classes.

Aspire interface
----------------

.. autoclass:: aspire.Aspire
   :members:
   :undoc-members:
   :show-inheritance:

Samples utilities
-----------------

.. automodule:: aspire.samples
   :members: Samples, SMCSamples
   :undoc-members:
   :show-inheritance:

History objects
---------------

.. automodule:: aspire.history
   :members: History, FlowHistory, SMCHistory
   :undoc-members:
   :show-inheritance:
